psychopy_ext.exp.Task.create_exp_plan — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.Task.create_exp_plan

`Task.` `create_exp_plan`()

  Put together trials into `self.exp_plan`.

  Example:

      self.exp_plan = []
      for ...:
          exp_plan.append([
              OrderedDict([
                  ('cond', cond),
                  ('name', names[cond]),
                  ('onset', ''),
                  ('dur', trial_dur),
                  ('corr_resp', corr_resp),
                  ('subj_resp', ''),
                  ('accuracy', ''),
                  ('rt', ''),
                  ])
              ])